@@ -642,7 +642,7 @@ CREATE TABLE IF NOT EXISTS multipart_uploads (
     backup_id int(11) NOT NULL,
     upload_id varchar(255) NOT NULL,
     bucket varchar(255) NOT NULL,
-    key varchar(500) NOT NULL,
+    `key` varchar(500) NOT NULL,
     file_path varchar(500) NOT NULL,
     file_size bigint NOT NULL,
     chunk_size int NOT NULL,
