@@ -432,6 +432,11 @@ try {
             $escapedDomain = str_replace(['\\', '%', '_'], ['\\\\', '\\%', '\\_'], $domain);
             $escapedContainer = str_replace(['\\', '%', '_'], ['\\\\', '\\%', '\\_'], $containerName);
 
+            // Create sanitized domain pattern (periods replaced with underscores)
+            // Database backups sanitize domain names: dev.example.com → dev_example_com
+            $sanitizedDomain = str_replace('.', '_', $domain);
+            $escapedSanitizedDomain = str_replace(['\\', '%', '_'], ['\\\\', '\\%', '\\_'], $sanitizedDomain);
+
             // Query backups for this domain - include all relevant backup types
             // wordpress: auto WordPress backups
             // site: full site backups (may contain WordPress)
@@ -456,6 +461,7 @@ try {
                 AND (
                     bh.backup_name LIKE ?
                     OR bh.backup_name LIKE ?
+                    OR bh.backup_name LIKE ?
                 )
                 AND bh.backup_type IN ('wordpress', 'site', 'database', 'userfiles')
                 AND bh.status = 'completed'
@@ -465,7 +471,8 @@ try {
             $stmt->execute([
                 $site['user'],
                 '%' . $escapedDomain . '%',
-                '%' . $escapedContainer . '%'
+                '%' . $escapedContainer . '%',
+                '%' . $escapedSanitizedDomain . '%'
             ]);
             $backups = $stmt->fetchAll(PDO::FETCH_ASSOC);
 
